@@ -16,7 +16,7 @@ SCRIPT_DIR=$(dirname -z $0)
 GIT_ROOT=$(git -C $SCRIPT_DIR rev-parse --show-toplevel)
 CAFILE=$GIT_ROOT/priv/cacert.pem
 
-curl --time-cond $CAFILE --output $CAFILE https://download.process-one.net/cacert.pem
+curl --time-cond $CAFILE --output $CAFILE https://curl.haxx.se/ca/cacert.pem
 CHANGES=$(git -C $GIT_ROOT diff --name-only $CAFILE)
 if [ ! -z "$CHANGES" ]; then
     git -C $GIT_ROOT add $CAFILE
